package options;

import general.ChildPopulationMaker;
import general.Crossover;
import general.Developmental;
import general.EvaluatePopulationHandler;
import general.EvaluatePopulationParallelHandler;
import general.Fitness;
import general.Mutation;
import general.PlotFitnessInEvolution;
import general.SavePhenotype;
import selection.adult.AdultSelection;
import selection.adult.FullGenerationalReplacement;
import selection.parent.ParentSelection;
import selection.parent.RankSelection;
import selection.parent.TournamentSelection;
import swarm.DevelopmentalBooleanToFloat;
import swarm.FitnessSwarm;
import binary.ChildPopulationMakerBinary;
import binary.CrossoverBinary;
import binary.MutationBinaryProbability;

public class EAOptions {
	/** Main **/
	public int nmbOfGenerations = 30;
	public int populationSize = 10;

	/** Genotype and Phenotype **/
	public int genotypeLength = 65;
	public int bitsPerGene = 5;
	
	/** Selection **/
	public Fitness fitness = new FitnessSwarm("NORMAL", "OpposingWind"); // ArbitrationTest or OpposingWind or WindyAndHoles
	public AdultSelection adultSelection = new FullGenerationalReplacement();
	public ParentSelection parentSelection = new TournamentSelection(5, 0.3, this);
	
	/** Reproduction **/
	public double crossoverRate = 0.8;
	public double mutationRateOnIndividual = 1;
	public float mutationRateOnBit = 0.02f;
	public int numberOfElites = 1;
	public Crossover crossover = new CrossoverBinary();
	public ChildPopulationMaker childPopulationMaker = new ChildPopulationMakerBinary(this);
	public Mutation mutationType = new MutationBinaryProbability(mutationRateOnBit);
	
	public Developmental developmentalType = new DevelopmentalBooleanToFloat(this);
	public EvaluatePopulationHandler evaluatePopulationHandler = new EvaluatePopulationParallelHandler();

	public int plotterMode = PlotFitnessInEvolution.OFF;

	public boolean trainThresholds = false;
	public boolean trainAdvanced = false;
	public boolean measureTimeEveryGeneration = true;
	public Enum<SavePhenotype> savePhenotypes = SavePhenotype.SAVE_WHEN_FINISHED;
	public boolean saveStatistics = false;
}
