// This is made using ptplot5.7 library for plotting http://ptolemy.eecs.berkeley.edu/java/ptplot/
package plot;

import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import ptolemy.plot.Plot;
import ptolemy.plot.PlotApplication;
import util.Util;

public class PlotAssembleOnOff {
	private Plot plot;
	private PlotApplication app;
	public static final int assemble_on = 2, assemble_off = 7;
	private float[] fitnessSamples;

	public PlotAssembleOnOff(float maxWind, int samples) {
		plot = new Plot();
		plot.setTitle("Best found fitness");
		plot.setXLabel("Wind(m/s)");
		plot.setYLabel("Fitness");
		plot.setYRange(0, 1);
		plot.setXRange(0, maxWind);
		plot.setSize(400, 300);
		app = new PlotApplication(plot);
		plot.addLegend(assemble_on, "Assemble on");
		plot.addLegend(assemble_off, "Assemble off");
		app.setSize(400, 300);
		app.setLocation(0, 400);
		app.plot.setBackground(Color.WHITE);
		fitnessSamples = new float[samples];
	}
	
	public void addSample(int sample, float fitness){
		fitnessSamples[sample] = fitness;
	}

	public void updatePlot(float wind, int legend) {
		plot.addPoint(legend, wind, Util.average(fitnessSamples), true);
	}

	public void writePlotImage(String moreText) {
		Container c = app.getContentPane();
		BufferedImage im = new BufferedImage(c.getWidth(), c.getHeight(), BufferedImage.TYPE_INT_ARGB);
		c.paint(im.getGraphics());

		String fileName = "data/results/assembleonoffplots/AssembleOnOff - " + Util.dateAsString() + " - " + moreText + ".png";
		try {
			ImageIO.write(im, "png", new File(fileName));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}