// This is made using ptplot5.7 library for plotting http://ptolemy.eecs.berkeley.edu/java/ptplot/
package plot;

import general.Phenotype;
import general.Population;

import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;

import managers.ActionHandler;
import ptolemy.plot.Plot;
import ptolemy.plot.PlotApplication;
import util.Util;

public class PlotAssembleWeight {
	private Plot plot;
	private PlotApplication app;
	private float[] averageWeight;
	private float[] sdWeight;
	private final int[] behaviorsToCompare = new int[]{ActionHandler.COLLISION_AVOIDANCE, ActionHandler.GOAL_CONVERGING, ActionHandler.WANDER, ActionHandler.ASSEMBLE, ActionHandler.STAGNATION_RECOVERY, ActionHandler.MAINTAIN_TURN};

	public PlotAssembleWeight(float maxWind, int samples) {

		plot = new Plot();
		plot.setTitle("Self-Assemble weight");
		plot.setXLabel("Wind(m/s)");
		plot.setYLabel("Weight");
		plot.setYRange(0, 0.5);
		plot.setXRange(0, maxWind);
		plot.addLegend(3, "average for assemble");
		plot.addLegend(4, "SD for assemble");
		plot.addLegend(5, "average behavior");
//		plot.setColors(new Color[]{Color.MAGENTA, Color.CYAN, Color.YELLOW});
		app = new PlotApplication(plot);
		app.setSize(400, 300);
		app.setLocation(800, 400);
		app.plot.setBackground(Color.WHITE);
		averageWeight = new float[samples];
		sdWeight = new float[samples];

		for (int i = 0; i <= maxWind; i++) {
			plot.addPoint(5, i, 1.0f / behaviorsToCompare.length, true);
		}
	}

	@SuppressWarnings("unchecked")
	public void addSample(int sample) {
		float[] weightList = new float[Population.adultPopulation.size()];
		
		for (int i = 0; i < weightList.length; i++) {
			Phenotype<Float> p = (Phenotype<Float>) (Population.adultPopulation.get(i).getPhenotype());
			float individualSum = 0;
			
			for (int behaviorindex : behaviorsToCompare) {
				individualSum += p.getPhenotypeArray()[behaviorindex];
			}
			weightList[i]  = (float) (p.getPhenotypeArray()[ActionHandler.ASSEMBLE]/individualSum);
		}
		averageWeight[sample] = Util.average(weightList);
		sdWeight[sample] =  Util.standardDeviation(weightList, averageWeight[sample]);
	}

	public void updatePlot(float index) {
		System.out.println("Update " + Util.average(averageWeight)); 
		plot.addPoint(3, index, Util.average(averageWeight), true);
		plot.addPoint(4, index, Util.average(sdWeight), true);
	}

	public void writePlotImage(String moreText) {
		Container c = app.getContentPane();
		BufferedImage im = new BufferedImage(c.getWidth(), c.getHeight(), BufferedImage.TYPE_INT_ARGB);
		c.paint(im.getGraphics());

		String fileName = "data/results/assembleweightplots/AssembleWeight - " + Util.dateAsString() + " - " + moreText + ".png";
		try {
			ImageIO.write(im, "png", new File(fileName));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}