package plot;

import general.Phenotype;
import general.Population;

import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import ptolemy.plot.Plot;
import ptolemy.plot.PlotApplication;
import util.Util;

public class PlotConnectionUse {
	private Plot plot;
	private PlotApplication app;
	private float[] usageSample;
	
	public PlotConnectionUse(float maxWind, int samples){
		plot = new Plot();
		plot.setTitle("Average connection rate");
		plot.setXLabel("Wind(m/s)");
		plot.setYLabel("ConnectionRate");
		plot.setYRange(0, 1);
		plot.setXRange(0, maxWind);
		app = new PlotApplication(plot);
		plot.addLegend(6, "avg connection rate");
		usageSample = new float[samples];
		app.setSize(400, 300);
		app.setLocation(400, 400);
		app.plot.setBackground(Color.WHITE);
		
	}
	
	@SuppressWarnings("unchecked")
	public void addSample(int sample){
		double[] usageList = new double[Population.adultPopulation.size()];
		
		for (int i = 0; i < usageList.length; i++) {
			Phenotype<Float> p = (Phenotype<Float>) (Population.adultPopulation.get(i).getPhenotype());
			usageList[i] = p.getConnectionRate();
		}
		usageSample[sample] =  (float) Util.average(usageList);
	}
	
	public void updatePlot(float wind) {
		plot.addPoint(6, wind, Util.average(usageSample), true);
	}

	public void writePlotImage(String moreText) {
		Container c = app.getContentPane();
		BufferedImage im = new BufferedImage(c.getWidth(), c.getHeight(), BufferedImage.TYPE_INT_ARGB);
		c.paint(im.getGraphics());

		String fileName = "data/results/connectionrateplots/ConnectionRate - " + Util.dateAsString() + " - " + moreText + ".png";
		try {
			ImageIO.write(im, "png", new File(fileName));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
