package plot;

import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;

import options.EAOptions;
import ptolemy.plot.Plot;
import ptolemy.plot.PlotApplication;
import util.Util;

public class PlotSamples {

	private final boolean connectedPoints = true;
	private Plot plot;
	private PlotApplication app;
	private EAOptions eaOptions;
	private float[][][] data;
	private int samples;

	public PlotSamples(int samples, EAOptions eaOptions) {
		this.eaOptions = eaOptions;
		this.samples = samples;
		plot = new Plot();
		plot.setTitle("Evolution");
		plot.setXLabel("Generation");
		plot.setYLabel("Fitness");
		plot.setYRange(0, 1);
		plot.setXRange(0, eaOptions.nmbOfGenerations);
		app = new PlotApplication(plot);

		plot.addLegend(0, "Average");
		plot.addLegend(1, "Max");
		plot.addLegend(2, "SD");
		app.setSize(400, 300);
		app.setLocation(0, 400);
		app.plot.setBackground(Color.WHITE);

		data = new float[samples][eaOptions.nmbOfGenerations][3];
	}

	public void addDataFromSample(int sample, float[][] sampleStatistics) {
		data[sample] = sampleStatistics;
	}

	private float[] getAverageValuesForGeneration(int generation) {
		float[] sum = new float[3];
		for (int sample = 0; sample < data.length; sample++) {
			for (int statType = 0; statType < data[sample][generation].length; statType++) {
				sum[statType] += data[sample][generation][statType];
			}
		}

		float[] average = new float[3];
		for (int statType = 0; statType < average.length; statType++) {
			average[statType] = sum[statType] / data.length;
		}

		return average;
	}

	public void drawPlot(String environments) {
		float[] averageValues = new float[3];
		for (int gen = 0; gen < eaOptions.nmbOfGenerations; gen++) {
			averageValues = getAverageValuesForGeneration(gen);
			for (int statType = 0; statType < averageValues.length; statType++) {
				plot.addPoint(statType, gen + 1, averageValues[statType], connectedPoints);
			}
		}

		writePlotImage(environments + " - " + samples);
	}

	public void writePlotImage(String moreText) {
		Container c = app.getContentPane();
		BufferedImage im = new BufferedImage(c.getWidth(), c.getHeight(), BufferedImage.TYPE_INT_ARGB);
		c.paint(im.getGraphics());

		String fileName = "data/results/fitnessplots/Fitness Plot - " + Util.dateAsString() + " - " + moreText + ".png";
		try {
			ImageIO.write(im, "png", new File(fileName));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
