package run;

import general.Individual;
import general.PlotFitnessInEvolution;
import general.SavePhenotype;
import options.EAOptions;
import options.SimulatorOptions;
import plot.PlotAssembleOnOff;
import plot.PlotAssembleWeight;
import plot.PlotConnectionUse;
import selection.parent.TournamentSelection;
import swarm.FitnessSwarm;
import swarm.RunEA;
import util.PerformanceTester;

public class RunAssembleAll {
	private RunEA ea;
	private EAOptions eaOptions;
	private PlotAssembleOnOff plotOnOff;
	private PlotConnectionUse plotConnectionUse;
	private PlotAssembleWeight plotWeight;

	public void run(String type, float windStart, float dWind, float maxWind, int samples, boolean forceAssembleOn, String environment) {
		PerformanceTester.startTest("All runs");
		ea = new RunEA();

		eaOptions = new EAOptions();
		eaOptions.measureTimeEveryGeneration = false;
		eaOptions.plotterMode = PlotFitnessInEvolution.OFF;
		eaOptions.savePhenotypes = SavePhenotype.NEVER_SAVE;

		eaOptions.populationSize = 20;
		eaOptions.nmbOfGenerations = 25;
		eaOptions.mutationRateOnBit = 0.015f;//1/numberOfBytes
		eaOptions.crossoverRate = 0.6f;
		eaOptions.numberOfElites = 2;

		eaOptions.parentSelection = new TournamentSelection(5, 0.3, eaOptions);
		
		eaOptions.trainAdvanced = true;
		
		eaOptions.trainThresholds = false; // 50 min --94 side obstacle
//		eaOptions.trainThresholds = true; // 77 min
		
		plotOnOff = new PlotAssembleOnOff(maxWind, samples);
		plotConnectionUse = new PlotConnectionUse(maxWind, samples);
		plotWeight = new PlotAssembleWeight(maxWind, samples);

		for (float wind = windStart; wind <= maxWind; wind += dWind) {
			runSamples(environment, type, wind, samples, forceAssembleOn, PlotAssembleOnOff.assemble_on);
			runSamples(environment, type, wind, samples, forceAssembleOn, PlotAssembleOnOff.assemble_off);
		}
		PerformanceTester.endTest("All runs");
		plotOnOff.writePlotImage(environment);
		String name = environment;
		if(forceAssembleOn)
			name += " - assembly forced on";
		plotConnectionUse.writePlotImage(name);
		plotWeight.writePlotImage(environment);
	}

	private void runSamples(String environment, String type, float wind, int samples, boolean forceAssembleOn, int legend) {
		SimulatorOptions.allowSelfAssembling = (legend == PlotAssembleOnOff.assemble_on) ? true : false;
		SimulatorOptions.forceSelfAssembling = SimulatorOptions.allowSelfAssembling && forceAssembleOn;
		eaOptions.fitness = new FitnessSwarm(type, environment + wind);
		
		for (int sample = 0; sample < samples; sample++) {
			Individual best = ea.runEA(eaOptions);
			plotOnOff.addSample(sample, (float) best.getFitness());
			if(SimulatorOptions.allowSelfAssembling){
				plotConnectionUse.addSample(sample);
				plotWeight.addSample(sample);
			}
			System.out.println(wind + " " + SimulatorOptions.allowSelfAssembling + " " + sample); 
		}
		plotOnOff.updatePlot(wind, legend);
		plotConnectionUse.updatePlot(wind);
		plotWeight.updatePlot(wind);
	}

	/** Main */
	public static void main(String[] args) {
		RunAssembleAll assembleAdvantageTest = new RunAssembleAll();

		assembleAdvantageTest.run("AVERAGE3", 0f, 1f, 8f, 8, false, "SideWindObstacles");
	}
}
