package run;

import java.io.FileWriter;

import general.Individual;
import general.PlotFitnessInEvolution;
import general.SavePhenotype;
import options.EAOptions;
import options.SimulatorOptions;
import plot.PlotSamples;
import selection.parent.RankSelection;
import selection.parent.TournamentSelection;
import swarm.FitnessSwarm;
import swarm.RunEA;
import util.PerformanceTester;

public class RunSingleEvolution {

	public static void runSingleEa(boolean useAssembly, boolean openReplayAfter, int samples, String method, String environment) {
		SimulatorOptions.allowSelfAssembling = useAssembly;

		// Setup run options
		EAOptions eaOptions = new EAOptions();
		if (samples == 1) {
			eaOptions.plotterMode = PlotFitnessInEvolution.PLOT_AND_WRITE_IMAGE;
		} else {

		}

		eaOptions.fitness = new FitnessSwarm(method, environment);
//		eaOptions.savePhenotypes = SavePhenotype.SAVE_DURING;
		eaOptions.populationSize = 20;//20;
		eaOptions.nmbOfGenerations = 50;//50;
		eaOptions.mutationRateOnBit = 0.015f;//1/numberOfBytes
		eaOptions.crossoverRate = 0.6f;
		eaOptions.numberOfElites = 2;
		
		eaOptions.parentSelection = new TournamentSelection(5, 0.3, eaOptions);
		
		eaOptions.saveStatistics = true;
		eaOptions.trainThresholds = true;
		eaOptions.trainAdvanced = true;

		PlotSamples plotter = new PlotSamples(samples, eaOptions);

		// run
		for (int i = 0; i < samples; i++) {
			System.out.println("Sample: " + i);
			RunEA ea = new RunEA();
			Individual best = ea.runEA(eaOptions);
			System.out.println(best.getPhenotype().toString());
			plotter.addDataFromSample(i, ea.getStatistics());
		}
		plotter.drawPlot(environment);

		// Open replay
		if (openReplayAfter) {
			new Replay();
		}
	}

	/** Main */
	public static void main(String[] args) {
		PerformanceTester.startTest("whole run");
		RunSingleEvolution.runSingleEa(true, true, 1, "AVERAGE5", "OpposingWindObstacles6f"); // Average 5
		PerformanceTester.endTest("whole run");
	}
}
