package util;

import general.Individual;
import general.Population;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.FontMetrics;
import java.awt.Graphics2D;
import java.awt.Stroke;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import objects.Wall;

import org.jbox2d.common.Vec2;

public class Util {
	public static final DecimalFormat decimalTwo = new DecimalFormat("#.##");
	public static final DecimalFormat decimalThree = new DecimalFormat("#.###");
	public static final DecimalFormat decimalFour = new DecimalFormat("#.####");

	public static final Stroke veryThinLine = new BasicStroke(0.5f);
	public static final Stroke thinLine = new BasicStroke(1);
	public static final Stroke mediumLine = new BasicStroke(2);
	public static final Stroke thickLine = new BasicStroke(3);
	public static final Stroke dashedLine = new BasicStroke(1.0f, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER, 10.0f, new float[] { 10f }, 0.0f);

	public static final int RED = 0, GREEN = 1, BLUE = 2;

	public static String fixedDecimals(float d, int decimals) {
		String decimalformat = "#.";
		for (int i = 0; i < decimals; i++) {
			decimalformat += "#";
		}
		DecimalFormat decimal = new DecimalFormat(decimalformat);
		return decimal.format(d);
	}

	public static String StringDoubleTwo(float number) {
		return decimalTwo.format(number);
	}

	public static String StringDoubleThree(float number) {
		return decimalThree.format(number);
	}

	public static String StringDoubleFour(float number) {
		return decimalFour.format(number);
	}

	public static float normalizeAngle(float angle) {
		angle = (float) (angle % (2 * Math.PI));
		if (angle < 0) {
			angle += (float) (2 * Math.PI);
		}

		return angle;
	}

	public static Vec2 createVec2(float length, float angle) {
		Vec2 v = new Vec2();
		v.x = (float) (Math.cos(angle) * length);
		v.y = (float) (Math.sin(angle) * length);
		return v;
	}

	public static float getVec2Angle(Vec2 diff) {
		return Util.normalizeAngle((float) (Math.atan2(diff.y, diff.x)));
	}

	public static int getQuadrantOfAngle(float angle) {
		angle = Util.normalizeAngle(angle);
		if (angle <= (float) (Math.PI / 2)) {
			return 1;
		} else if (angle <= (float) (Math.PI)) {
			return 2;
		} else if (angle <= (float) (3 * Math.PI / 2)) {
			return 3;
		} else {
			return 4;
		}
	}

	public static float getNormalBetweenWallAndSensor(Wall wall, Vec2 sensorPosition) {
		Vec2 wallPosition = wall.getBody().getPosition();
		Vec2 closestWallPosition = new Vec2();

		if (wall.isVertical()) {
			closestWallPosition.x = wallPosition.x;
			closestWallPosition.y = sensorPosition.y;
		} else {
			closestWallPosition.x = sensorPosition.x;
			closestWallPosition.y = wallPosition.y;
		}

		float distance = (float) Math.sqrt(Math.pow(closestWallPosition.x - sensorPosition.x, 2) + Math.pow(closestWallPosition.y - sensorPosition.y, 2));
		return distance;
	}

	public static String arrayToString(float[] array) {
		String s = "( ";
		for (float f : array) {
			s += "" + f + " ";
		}
		s += ")";
		return s;
	}

	public static float getDifferenceBetweenAngles(float angleA, float angleB) {
		float a = (float) (Math.abs(angleA - angleB));

		// Special case if angles are on different sides of 0
		if ((Util.getQuadrantOfAngle(angleA) == 1 && Util.getQuadrantOfAngle(angleB) == 4) || (Util.getQuadrantOfAngle(angleA) == 4 && Util.getQuadrantOfAngle(angleB) == 1)) {
			a = (float) (Math.PI * 2 - a);
		}

		return a;
	}

	public static String dateAsString() {
		DateFormat df = new SimpleDateFormat("MM-dd (HHmmss)");
		return df.format(new Date());
	}

	public static String floatToDecimalAndExponentialFormat(float a) {
		Double b = (double) a;
		if (b > 1000) {
			NumberFormat formatter = new DecimalFormat("#.##E0");
			return "" + formatter.format(a);
		} else {
			return "" + StringDoubleFour(a);
		}
	}

	public static Color getClosestColor(float[] rgb) {
		// Normalize
		Color[] colorlist = new Color[] { Color.RED, Color.BLUE, Color.GREEN, Color.YELLOW, Color.CYAN, Color.WHITE, Color.BLACK };
		float[] normalizedRgb = normalizeRgb(rgb);

		// Classify against standard colors
		float best = Float.MAX_VALUE;
		int index = 0;
		for (int i = 0; i < colorlist.length; i++) {
			float t = getColorDifference(colorlist[i], normalizedRgb);
			if (t < best) {
				best = t;
				index = i;
			}
		}

		// Return best
		return colorlist[index];
	}

	private static float[] normalizeRgb(float[] rgb) {
		float[] normalizedRgb = new float[3];
		float highest = 0;

		for (int i = 0; i < 3; i++) {
			if (rgb[i] > highest) {
				highest = rgb[i];
			}
		}

		if (highest > 0) {
			for (int i = 0; i < 3; i++) {
				normalizedRgb[i] = rgb[i] / highest;
			}
		}

		return normalizedRgb;
	}

	public static float getColorDifference(Color c, float[] normalizedRgb) {
		float dif = 0;
		dif += Math.abs(normalizedRgb[0] - c.getRed() / 255);
		dif += Math.abs(normalizedRgb[1] - c.getGreen() / 255);
		dif += Math.abs(normalizedRgb[2] - c.getBlue() / 255);
		return dif;
	}

	public static double average(double[] numbers) {
		double sum = 0.0;
		for (int i = 0; i < numbers.length; i++) {
			sum += numbers[i];
		}
		return sum / numbers.length;
	}

	public static double median(double[] numbers) {
		java.util.Arrays.sort(numbers);

		if (numbers.length % 2 == 0) {
			return (numbers[numbers.length / 2] + numbers[numbers.length / 2 - 1]) / 2;
		} else {
			return numbers[numbers.length / 2];
		}
	}

	public static int getStringWithOnScreen(Graphics2D g, String s) {
		FontMetrics metrics = g.getFontMetrics(g.getFont());
		return metrics.stringWidth(s);
	}

	public static double standardDeviation(double[] list, double average) {
		double variance = 0.0;
		for (double d : list) {
			variance += Math.pow((d - average), 2);
		}

		variance = variance / list.length;

		return Math.sqrt(variance);
	}
	
	public static float standardDeviation(float[] list, float average) {
		float variance = 0.0f;
		for (float d : list) {
			variance += Math.pow((d - average), 2);
		}

		variance = variance / list.length;

		return (float)Math.sqrt(variance);
	}

	public static void main(String[] args) {
		// Used to test utils
		System.out.println(median(new double[] { 1, 3, 3, 1, 9, 2 }));
	}

	public static float average(float[] numbers) {
		float sum = 0.0f;
		for (int i = 0; i < numbers.length; i++) {
			sum += numbers[i];
		}
		return sum / numbers.length;
	}
}
