package behaviors;

import java.awt.Color;
import java.util.ArrayList;
import managers.ActionHandler;
import robot.LightSensor;
import robot.SensorHandler;
import controller.ArbitrationController;

public class AssembleBehavior extends ConvergingBehavior{
	private float distanceThresholdToGrip = 0.01f;
	private float lightThresholdToGrip = 0.9f;
	
	public AssembleBehavior(ArbitrationController controller) {
		super(controller);
		this.name = "Self-Assemble";
	}

	@Override
	public void updateVote(float elapsedTime) {
		resetVote();
		if (controller.getRobot().getConnectionJoint() != null) {
			return;
		}
		ArrayList<LightSensor> sensors = controller.getRobot().getSensorHandler().getLightSensors();

		// Special case Front, when close enough to connect
		if (atGripDistance(SensorHandler.FRONT) && isRightColor(sensors.get(SensorHandler.FRONT).getClosestColorToSensorColor())) {
			vote[ActionHandler.GRIP] = POSITIVE_VOTE;
			return;
		}
		
		voteToConvergeInDirections();

		// Special case Back, when it sees a robot behind and waits for it
		if (isClose(SensorHandler.BACK) && sensors.get(SensorHandler.BACK).getClosestColorToSensorColor() == Color.BLUE) {
			vote[ActionHandler.FORWARD] -= (1 - getDistanceFromSensor(SensorHandler.BACK) / controller.getDistanceThresholdFar());
			vote[ActionHandler.FORWARD_LEFT] -= (1 - getDistanceFromSensor(SensorHandler.BACK) / controller.getDistanceThresholdFar());
			vote[ActionHandler.FORWARD_RIGHT] -= (1 - getDistanceFromSensor(SensorHandler.BACK) / controller.getDistanceThresholdFar());
//			vote[ActionHandler.BACKWARD] = getDistanceFromSensor(SensorHandler.BACK) / controller.getDistanceThreshold();
		}
		
		normalizeVotes();
	}
	
	

	@Override
	public boolean isRightColor(Color c){
		return c == Color.GREEN;
	}

	private boolean atGripDistance(int sensorDirectionIndex) {
		return (getDistanceFromSensor(sensorDirectionIndex) <= distanceThresholdToGrip && getLightFromSensor(sensorDirectionIndex) >= lightThresholdToGrip);
	}

}
