package behaviors;

import managers.ActionHandler;
import controller.ArbitrationController;

public class AssembleRecoveryBehavior extends Behavior {

	private float startTimeRecovery;
	private boolean recoveryMode = false;
	private float timeToStartStagnation = 3;
	private float timeToEndRecovery = 3;

	public AssembleRecoveryBehavior(ArbitrationController controller) {
		super(controller);
		this.name = "Assemble Recovery";
	}

	@Override
	public void updateVote(float elapsedTime) {
		resetVote();

		// not connected
		if (controller.getRobot().getConnectionJoint() == null) {
			// if in recovery mode
			if (recoveryMode && elapsedTime - startTimeRecovery < timeToEndRecovery) {
				vote[ActionHandler.GRIP] = NEGATIVE_VOTE;
				vote[ActionHandler.BACKWARD] = POSITIVE_VOTE;
			} else {
				recoveryMode = false;
			}
			return;
		}

		// Check if recovery mode should be started
		if (controller.getRobot().getSensorHandler().getAccelerometer().getTimeSinceMoved() > timeToStartStagnation) {
			vote[ActionHandler.RELEASEGRIP] = POSITIVE_VOTE;
			recoveryMode = true;
			startTimeRecovery = elapsedTime;
		}
	}

	public boolean isInRecoveryMode() {
		return recoveryMode;
	}

	public float getTimeToStartStagnation() {
		return timeToStartStagnation;
	}
}
