package behaviors;

import java.util.ArrayList;

import robot.LightSensor;
import robot.SensorHandler;
import controller.ArbitrationController;

public abstract class Behavior {
	protected String name;

	public String getName() {
		return name;
	}

	protected ArbitrationController controller;
	protected int nmbOfActions = 8;
	protected final static float POSITIVE_VOTE = 1f, NEGATIVE_VOTE = -1f;
	protected float[] vote;

	public Behavior(ArbitrationController controller) {
		this.controller = controller;
	}

	public float[] getVote() {
		if (vote == null) {
			vote = new float[nmbOfActions];
		}
		return vote;
	}

	public abstract void updateVote(float elapsedTime);

	public void resetVote() {
		if (vote == null) {
			vote = new float[nmbOfActions];
		} else {
			for (int i = 0; i < vote.length; i++) {
				vote[i] = 0f;
			}
		}
	}

	public float getDistanceFromSensor(int sensorDirectionIndex) {
		return controller.getRobot().getSensorHandler().getLightSensors().get(sensorDirectionIndex).getDistanceValue();
	}

	public float getLightFromSensor(int sensorDirectionIndex) {
		return controller.getRobot().getSensorHandler().getLightSensors().get(sensorDirectionIndex).getLightValue();
	}

	public boolean isClose(int sensorDirectionIndex) {
		return getDistanceFromSensor(sensorDirectionIndex) < controller.getDistanceThresholdFar();
	}

	public boolean isCloseToLight(int sensorDirection) {
		return getLightFromSensor(sensorDirection) >= controller.getLightThresholdFar();
	}

	public boolean isSensedDistanceLow(int sensorDirectionIndex, float distanceThreshold) {
		return getDistanceFromSensor(sensorDirectionIndex) <= distanceThreshold;
	}

	public int getSensorWithMinimalDistance() {
		ArrayList<LightSensor> sensors = controller.getRobot().getSensorHandler().getLightSensors();
		float closest = Float.MAX_VALUE;
		float distanceThreshold = controller.getDistanceThresholdFar();
		int closestSensor = 0;

		for (int i = 0; i < sensors.size(); i++) {
			float distance = getDistanceFromSensor(i);

			if (isSensedDistanceLow(i, distanceThreshold) && distance <= closest) {
				closestSensor = i;
				closest = distance;
			}
		}
		return closestSensor;
	}

	public void voteWithProbability(int index, float probability) {
		if (Math.random() <= probability) {
			vote[index] = POSITIVE_VOTE;
		} else {
			vote[index] = 0.2f;
		}
	}

	protected void normalizeVotes() {
		for (int i = 0; i < vote.length; i++) {
			if (vote[i] > 1) {
				vote[i] = 1;
			} else if (vote[i] < -1) {
				vote[i] = -1;
			}
		}
	}
}
