package behaviors;

import java.awt.Color;

import managers.ActionHandler;
import robot.LightSensor;
import robot.SensorHandler;
import controller.ArbitrationController;

public class CollisionAvoidanceBehavior extends Behavior {
	float shortestDistance, longDistance;

	public CollisionAvoidanceBehavior(ArbitrationController controller) {
		super(controller);
		this.name = "Collision Avoidance";
	}

	@Override
	public void updateVote(float elapsedTime) {
		resetVote();

		shortestDistance = shortestDistance();
		longDistance = controller.getDistanceThresholdFar() - shortestDistance;
		decideVoteInDirection(SensorHandler.FRONT, ActionHandler.FORWARD);
		decideVoteInDirection(SensorHandler.RIGHT, ActionHandler.TURN_HARD_RIGHT);
		decideVoteInDirection(SensorHandler.LEFT, ActionHandler.TURN_HARD_LEFT);
		decideVoteInDirection(SensorHandler.BACK, ActionHandler.BACKWARD);
		decideVoteInDirections(SensorHandler.FRONT_LEFT, SensorHandler.FRONT, ActionHandler.FORWARD_LEFT);
		decideVoteInDirections(SensorHandler.FRONT_RIGHT, SensorHandler.FRONT, ActionHandler.FORWARD_RIGHT);
		normalizeVotes();
	}

	private float shortestDistance() {
		float minDistance = Float.MAX_VALUE;
		for (LightSensor s : controller.getRobot().getSensorHandler().getLightSensors()) {
			boolean closeToOkLightSource = s.getLightValue() > 0.1f && isOkColor(s.getClosestColorToSensorColor());
			if (s.getDistanceValue() < minDistance && !closeToOkLightSource)
				minDistance = s.getDistanceValue();
		}
		return minDistance;
	}

	private boolean isOkColor(Color closestColor) {
		return closestColor == Color.GREEN || closestColor == Color.BLUE || closestColor == Color.YELLOW || closestColor == Color.RED;
	}

	private void decideVoteInDirection(int sensorDirectionIndex, int actionIndex) {
		if (isClose(sensorDirectionIndex)) {
			float extraDistance = getDistanceFromSensor(sensorDirectionIndex) - shortestDistance;
			vote[actionIndex] = (extraDistance - longDistance) / longDistance;
		}
	}

	private void decideVoteInDirections(int sensorDirectionIndexOne, int sensorDirectionIndexTwo, int actionIndex) {
		if (isClose(sensorDirectionIndexOne) || isClose(sensorDirectionIndexTwo)) {
			float extraDistance = Math.min(getDistanceFromSensor(sensorDirectionIndexOne), getDistanceFromSensor(sensorDirectionIndexTwo)) - shortestDistance;
			vote[actionIndex] = (extraDistance - longDistance) / longDistance;
		}
	}
}
