package behaviors;

import java.awt.Color;

import managers.ActionHandler;
import robot.LightSensor;
import robot.SensorHandler;
import controller.ArbitrationController;

public abstract class ConvergingBehavior extends Behavior {
	
	private final float minLight = 0.0f;
	
	public ConvergingBehavior(ArbitrationController controller) {
		super(controller);
	}

	protected void voteToConvergeInDirection(int sensorDirectionIndex, int actionIndex, float highestLight) {
		if(highestLight == 0.0)
			return;
		
		Color closestColor = controller.getRobot().getSensorHandler().getLightSensors().get(sensorDirectionIndex).getClosestColorToSensorColor();
		
		if (isCloseToLight(sensorDirectionIndex) && isRightColor(closestColor)) {
			float light = getLightFromSensor(sensorDirectionIndex);
			vote[actionIndex] += Math.min(light / highestLight, 1f);
		}
	}

	protected void voteToConvergeInDiagonallyDirection(int sensorDirectionIndex, int actionIndexForwardTurn, int actionIndexHardTurn, float highestLight) {
		if(highestLight == 0.0)
			return;
		
		LightSensor sensor = controller.getRobot().getSensorHandler().getLightSensors().get(sensorDirectionIndex);
		Color closetsColor = sensor.getClosestColorToSensorColor();
		
		if (isCloseToLight(sensorDirectionIndex) && isRightColor(closetsColor)) {
			float light = getLightFromSensor(sensorDirectionIndex);
			if (sensor.getDistanceValue() < 0.1) {
				vote[actionIndexHardTurn] += Math.min(light / highestLight, 1f);
			} else {
				vote[actionIndexForwardTurn] += Math.min(light / highestLight, 1f);
			}
		}
	}
	
	protected float highestLightValue(){
		float highestLight = minLight;
		for (LightSensor s : controller.getRobot().getSensorHandler().getLightSensors()) {
			if(s.getLightValue() > highestLight && isRightColor(s.getClosestColorToSensorColor()))
				highestLight = s.getLightValue();
		}
		return highestLight;
	}
	
	protected void voteToConvergeInDirections() {
		float highestLightValue = highestLightValue();
		if(highestLightValue == 0)
			return;
		voteToConvergeInDirection(SensorHandler.FRONT, ActionHandler.FORWARD, highestLightValue);
		voteToConvergeInDirection(SensorHandler.LEFT, ActionHandler.TURN_HARD_LEFT, highestLightValue);
		voteToConvergeInDirection(SensorHandler.RIGHT, ActionHandler.TURN_HARD_RIGHT, highestLightValue);
		voteToConvergeInDirection(SensorHandler.BACK, ActionHandler.TURN_HARD_LEFT, highestLightValue);
		voteToConvergeInDirection(SensorHandler.BACK, ActionHandler.TURN_HARD_RIGHT, highestLightValue);

		voteToConvergeInDiagonallyDirection(SensorHandler.FRONT_LEFT, ActionHandler.FORWARD_LEFT, ActionHandler.TURN_HARD_LEFT, highestLightValue);
		voteToConvergeInDiagonallyDirection(SensorHandler.FRONT_RIGHT, ActionHandler.FORWARD_RIGHT, ActionHandler.TURN_HARD_RIGHT, highestLightValue);
		
	}
	
	public abstract boolean isRightColor(Color c);
	
}
