package behaviors;

import java.util.ArrayList;

import managers.ActionHandler;

import robot.LightSensor;
import robot.SensorHandler;

import controller.ArbitrationController;

public class HoleAvoidanceBehavior extends Behavior{

	public HoleAvoidanceBehavior(ArbitrationController controller) {
		super(controller);
		this.name = "Hole Avoidance";
	}

	@Override
	public void updateVote(float elapsedTime) {
		resetVote();
		decideVoteInDirection(SensorHandler.FRONT, ActionHandler.FORWARD);
		decideVoteInDirection(SensorHandler.RIGHT, ActionHandler.TURN_HARD_RIGHT);
		decideVoteInDirection(SensorHandler.LEFT, ActionHandler.TURN_HARD_LEFT);
		decideVoteInDirection(SensorHandler.BACK, ActionHandler.BACKWARD);
		
		decideVoteInDirections(SensorHandler.FRONT_RIGHT, SensorHandler.FRONT, ActionHandler.FORWARD_RIGHT);
		decideVoteInDirections(SensorHandler.FRONT_LEFT, SensorHandler.FRONT, ActionHandler.FORWARD_LEFT);
		decideVoteInDirections(SensorHandler.FRONT_RIGHT, SensorHandler.FRONT, ActionHandler.FORWARD);
		decideVoteInDirections(SensorHandler.FRONT_LEFT, SensorHandler.FRONT, ActionHandler.FORWARD);
		
	}
	
	private void decideVoteInDirection(int sensorDirectionIndex, int actionIndex) {
		ArrayList<LightSensor> sensors = controller.getRobot().getSensorHandler().getLightSensors();
		if (sensors.get(sensorDirectionIndex).isHoleDetectedInAnyRange()) {
			vote[actionIndex] = -1f;
		}
	}
	
	private void decideVoteInDirections(int sensorDirectionIndexOne, int sensorDirectionIndexTwo, int actionIndex) {
		ArrayList<LightSensor> sensors = controller.getRobot().getSensorHandler().getLightSensors();
		if (sensors.get(sensorDirectionIndexOne).isHoleDetectedInAnyRange() || sensors.get(sensorDirectionIndexTwo).isHoleDetectedInAnyRange()) {
			vote[actionIndex] = -1f;
		}
	}

}
