package behaviors;

import managers.ActionHandler;
import robot.SensorHandler;
import controller.ArbitrationController;

public class StagnationRecoveryBehavior extends Behavior {
	private float startTimeRecovery;
	private boolean recoveryMode = false;
	private int lastActionBeforeStagnation;
	private float timeToStartStagnation = 3;
	private float timeToEndRecovery = 3;

	public StagnationRecoveryBehavior(ArbitrationController controller) {
		super(controller);
		this.name = "Stagnation Recovery";
	}
	@Override
	public void updateVote(float elapsedTime) {
		resetVote();
		if (controller.getRobot().isConnected()) {
			return;
		}

		if (recoveryMode) {
			if (elapsedTime - startTimeRecovery < timeToEndRecovery) {

				decideVoteInDirection(SensorHandler.FRONT, ActionHandler.FORWARD);
				decideVoteInDirection(SensorHandler.FRONT_LEFT, ActionHandler.FORWARD_LEFT);
				decideVoteInDirection(SensorHandler.FRONT_RIGHT, ActionHandler.FORWARD_RIGHT);
				decideVoteInDirection(SensorHandler.RIGHT, ActionHandler.TURN_HARD_RIGHT);
				decideVoteInDirection(SensorHandler.LEFT, ActionHandler.TURN_HARD_LEFT);
				decideVoteInDirection(SensorHandler.BACK, ActionHandler.BACKWARD);

				if (lastActionBeforeStagnation >= 0) {
					vote[lastActionBeforeStagnation] = -1f;
				}
			} else {
				recoveryMode = false;
			}
			return;
		}

		if (controller.getRobot().getSensorHandler().getAccelerometer().getTimeSinceMoved() > timeToStartStagnation) {
			startTimeRecovery = elapsedTime;
			recoveryMode = true;
			lastActionBeforeStagnation = controller.getActionHandler().getBestActionIndex();
		}
	}


	private void decideVoteInDirection(int sensorDirectionIndex, int actionIndex) {
		float distance = getDistanceFromSensor(sensorDirectionIndex);
		vote[actionIndex] = Math.min(1, Math.max(0, distance / controller.getDistanceThresholdFar()));
	}
}
