package controller;

import environment_objects.World;

import java.awt.Graphics2D;

import joints.ConnectionJoint;



import objects.BodyObject;

import org.jbox2d.common.Vec2;

import robot.Robot;
import robot.SensorHandler;

public class ConnectionPullTestController extends Controller {

	float stopAtTime;
	World world;

	public ConnectionPullTestController(World world, float stopAtTime) {
		this.stopAtTime = stopAtTime;
		this.world = world;
	}

	public void run(float elapsedTime) {
		tryConnect(robot);
		robot.setWheelForces(1f, 1f);
		if (elapsedTime >= stopAtTime) {
			robot.setMotorIsRunning(false);
		}
//		System.out.println("Front sensor: "+robot.getSensorHandler().getLightSensors().get(SensorHandler.FRONT).getHoleDetectionOutputString());
//		System.out.println("FrontL sensor: "+robot.getSensorHandler().getLightSensors().get(SensorHandler.FRONT_LEFT).getHoleDetectionOutputString());
//		System.out.println("Left sensor: "+robot.getSensorHandler().getLightSensors().get(SensorHandler.LEFT).getHoleDetectionOutputString());
//		System.out.println("FrontR sensor: "+robot.getSensorHandler().getLightSensors().get(SensorHandler.FRONT_RIGHT).getHoleDetectionOutputString());

	}

	private boolean tryConnect(Robot a) {
		for (BodyObject b : world.getWorldObjects()) {
			if (b instanceof Robot && !b.equals(a) && isWithinReach(a, (Robot) b) && !world.isJointBetween(a, (Robot) b)) {
				Vec2[] connectionPoints = getConnectionPoints(a, (Robot) b);
				world.addConnectionJoint(new ConnectionJoint(a, (Robot) b, connectionPoints[0], connectionPoints[1]));
				// System.out.println("Connect!");
				return true;
			}
		}
		return false;
	}

	private boolean isWithinReach(Robot a, Robot b) {
		Vec2 aPosition = a.getBody().getPosition();
		Vec2 bPosition = b.getBody().getPosition();

		Vec2 distanceVec = aPosition.sub(bPosition);

		double distance = distanceVec.length() - (2 * Robot.getSize());
		return (distance < 0.03);
	}

	private Vec2[] getConnectionPoints(Robot a, Robot b) {
		Vec2[] points = new Vec2[2];

		Vec2 distanceVec = b.getBody().getPosition().sub(a.getBody().getPosition());

		points[0] = new Vec2();
		points[0] = distanceVec.mul(Robot.getSize() / distanceVec.length());

		points[1] = new Vec2();
		points[1] = distanceVec.mul(Robot.getSize() / distanceVec.length() * -1f);

		points[0] = a.getBody().getLocalPoint(a.getBody().getPosition().add(points[0]));
		points[1] = b.getBody().getLocalPoint(b.getBody().getPosition().add(points[1]));

		return points;
	}

	@Override
	public void draw(Graphics2D g) {
		// TODO Auto-generated method stub

	}
}
