package managers;

import java.util.ArrayList;


import robot.Robot;
import actions.ActuatorAction;
import behaviors.Behavior;

public class ActionHandler {

	private ArrayList<Behavior> behaviors;
	private ArrayList<ActuatorAction> actions;

	public ArrayList<ActuatorAction> getActions() {
		return actions;
	}


	private float[] behaviorWeights;
	private float[] votes;
	private ActuatorAction bestAction = null;
	private SituationWeightManager situationWeightManager;
	private Robot robot;

	public static final int TURN_HARD_LEFT = 0, FORWARD_LEFT = 1, FORWARD = 2, FORWARD_RIGHT = 3, TURN_HARD_RIGHT = 4,  BACKWARD = 5, GRIP = 6, RELEASEGRIP = 7;
	public static final int COLLISION_AVOIDANCE = 5, GOAL_CONVERGING = 0, WANDER = 1, ASSEMBLE = 3, ASSEMBLE_RECOVERY = 8, STAGNATION_RECOVERY = 7, MAINTAIN_TURN = 2, FOLLOW_LEADER = 4, HOLE_AVOIDANCE = 6;

	public ActionHandler(ArrayList<Behavior> behaviors, ArrayList<ActuatorAction> actions, Float[] phenotypeValues) {
		this.behaviors = behaviors;
		this.actions = actions;

		behaviorWeights = new float[this.behaviors.size()];
		for (int i = 0; i < behaviorWeights.length; i++) {
			behaviorWeights[i] = phenotypeValues[i];
		}

		votes = new float[this.actions.size()];
		
		situationWeightManager = new SituationWeightManager(behaviors);
	}

	public void updateBestAction(float elapsedTime) {
		for (int i = 0; i < votes.length; i++) {
			votes[i] = 0f;
		}

		situationWeightManager.updateSituationWeights();
		
		for (Behavior b : behaviors) {
			b.updateVote(elapsedTime);
			addVotes(b.getVote(), behaviorWeights[behaviors.indexOf(b)], situationWeightManager.getSituationWeights()[behaviors.indexOf(b)]);
		}
		
		float highest = -Float.MAX_VALUE;
		ArrayList<ActuatorAction> bestActions = new ArrayList<>();

		for (int i=0;i<votes.length;i++) {
			if (votes[i] > highest) {
				highest = votes[i];
				bestActions.clear();
				bestActions.add(actions.get(i));
			} else if (votes[i] == highest) {
				bestActions.add(actions.get(i));
			}
		}
		
		if(highest <= 0){
			bestAction = null;
		}else{
			int random = (int)(Math.random() * bestActions.size());
			bestAction = bestActions.get(random);
		}
	}

	public void addVotes(float[] vote, float weight, float situationWeight) {
		for (int i = 0; i < vote.length; i++) {
			votes[i] += vote[i] * weight * situationWeight;
		}
	}
	
	public float[] getBehaviorWeights() {
		return behaviorWeights;
	}

	public float[] getVotes() {
		return votes;
	}
	

	public ActuatorAction getBestAction() {
		return bestAction;
	}
	
	public int getBestActionIndex() {
		if(bestAction != null)
			return actions.indexOf(bestAction);
		else
			return -1;
	}
	
	public SituationWeightManager getSituationWeightManager(){
		return situationWeightManager;
	}
}
