// This is made using ptplot5.7 library for plotting http://ptolemy.eecs.berkeley.edu/java/ptplot/
package general;

import java.awt.Color;
import java.awt.Container;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import options.EAOptions;
import ptolemy.plot.Plot;
import ptolemy.plot.PlotApplication;
import util.Util;

public class PlotFitnessInEvolution {
	public static final int OFF = 0, PLOT = 1, WRITE_IMAGE = 2, PLOT_AND_WRITE_IMAGE = 3;
	private final boolean connectedPoints = true;
	private Plot plot;
	private PlotApplication app;
	private EAOptions eaOptions;

	public PlotFitnessInEvolution(int generations, EAOptions eaOptions) {
		this.eaOptions = eaOptions;

		if (eaOptions.plotterMode == OFF)
			return;
		plot = new Plot();
		plot.setTitle("Evolution");
		plot.setXLabel("Generation");
		plot.setYLabel("Fitness");
		plot.setYRange(0, 1);
		plot.setXRange(0, generations);
		app = new PlotApplication(plot);
		if (eaOptions.plotterMode != PLOT && eaOptions.plotterMode != PLOT_AND_WRITE_IMAGE) {
			app.setVisible(false);
		}
		plot.addLegend(0, "Average");
		plot.addLegend(1, "Max");
		plot.addLegend(2, "SD");
		app.setSize(400, 300);
		app.setLocation(0, 400);
		app.plot.setBackground(Color.WHITE);
	}

	public void updatePlot(int gen) {
		if (eaOptions.plotterMode == OFF)
			return;

		double sum = 0.0;
		double max = Double.MIN_VALUE;

		for (Individual adult : Population.adultPopulation) {
			sum += adult.getFitness();
			if (adult.getFitness() > max)
				max = adult.getFitness();
		}
		double average = sum / Population.adultPopulation.size();

		double[] list = new double[Population.adultPopulation.size()];
		for (int i = 0; i < list.length; i++) {
			list[i] = Population.adultPopulation.get(i).getFitness();
		}

		double standardDeviation = Util.standardDeviation(list, average);

		plot.addPoint(0, gen + 1, average, connectedPoints);
		plot.addPoint(1, gen + 1, max, connectedPoints);
		plot.addPoint(2, gen + 1, standardDeviation, connectedPoints);
	}

	public void writePlotImage(String moreText) {
		if (eaOptions.plotterMode != WRITE_IMAGE && eaOptions.plotterMode != PLOT_AND_WRITE_IMAGE) {
			return;
		}
		Container c = app.getContentPane();
		BufferedImage im = new BufferedImage(c.getWidth(), c.getHeight(), BufferedImage.TYPE_INT_ARGB);
		c.paint(im.getGraphics());

		String fileName = "data/results/fitnessplots/Fitness Plot - " + Util.dateAsString() + " - " + moreText + ".png";
		try {
			ImageIO.write(im, "png", new File(fileName));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}