package general;

import java.util.ArrayList;

public class Reproduction {
	private ArrayList<Genotype<?>> genotypes;
	
	// Reproduce genotypes from parents
	public ArrayList<Genotype<?>> reproduce(double crossoverRate, double mutationRate, Crossover crossoverType, Mutation mutationType, int numberOfElites) {
		// List of new genotypes for the next generation
		genotypes = new ArrayList<Genotype<?>>();
		
		// Crossover some genotypes from parents 
		crossoverWithTwoParents(crossoverRate,  crossoverType);
		
		// Copy the rest of genotypes
		for (Individual parent : Population.parentPopulation){
			genotypes.add(parent.getGenotype().copy());
		}
		
		Population.parentPopulation.clear();
		
		// Mutate some of the new genotypes
		mutation(mutationRate, mutationType);
		
		for (Individual elite : Population.elitePopulation) {
			genotypes.add(elite.getGenotype());
		}
		
		// return the new genotypes
		return genotypes;
	}

	// Make 2 new genotypes from crossover with 2 parents
	private void crossoverWithTwoParents(double crossoverRate, Crossover crossoverType) {
		int nmbOfCrossovers = (int) (Population.parentPopulation.size() * crossoverRate);
		
		while (nmbOfCrossovers >= 2 && Population.parentPopulation.size() >= 2) {
			// choose random parents
			Individual parent1 = Population.extractRandomParent(); 
			Individual parent2 = Population.extractRandomParent(); 
			// crossover genes
			genotypes.add(crossoverType.CrossoverGenes(parent1, parent2));
			genotypes.add(crossoverType.CrossoverGenes(parent2, parent1));
			nmbOfCrossovers -= 2;
		}
	}
	
	// Mutate some of the new genotypes, by flipping random bits
	private void mutation(double mutationRate, Mutation mutationType) {
		int mutationsToDo = (int) (mutationRate * genotypes.size());
		boolean[] alreadyMutated = new boolean[genotypes.size()];
		
		while (mutationsToDo > 0 ) {
			int random = (int) (Math.random() * genotypes.size());
			if(!alreadyMutated[random]){
				mutationType.mutateGenes(genotypes.get(random));
				alreadyMutated[random] = true;
				mutationsToDo -= 1;
			}
		}
	}
}
