package selection.parent;

import options.EAOptions;
import general.Population;


public class RankSelection extends ParentSelection {

	double min;
	double max;

	public RankSelection(EAOptions eaOptions, double min, double max) {
		super(eaOptions);
		this.min = min;
		this.max = max;
	}

	@Override
	public void select() {
		// select a list of individuals
		int nmbOfIndividuals = Population.adultPopulation.size();
		double[][] rank = new double[nmbOfIndividuals][2];
		if(min == 0.0 && max == 0.0){
			min = 0.5;
			max = 1;
		}
		for (int i = 0; i < nmbOfIndividuals; i++) {
			rank[i][0] = Population.adultPopulation.get(i).getFitness();
			rank[i][1] = (double) i;

		}

		// Sort list by rank[][0]
		rank = sortByFirstInDoubleArray2(rank);

		// Calculate probability values for each adult
		double[] values = new double[nmbOfIndividuals];
		double sumValues = 0.0;
		for (int i = 0; i < nmbOfIndividuals; i++) {
			values[i] = min + (max - min) * (getRankByIndex(rank, i)) / (nmbOfIndividuals - 1);
			sumValues += values[i];
		}
		
		// Turn list of values into list of limits for the rulettWheel
		double[] probabilityLimits = new double[nmbOfIndividuals];
		probabilityLimits[0] = values[0] / sumValues;
		for (int i = 1; i < nmbOfIndividuals; i++) {
			probabilityLimits[i] = (values[i] / sumValues) + probabilityLimits[i - 1];
		}
		
		// Run rulettWheel
		int[] parentIndexes = roulettWheel(probabilityLimits, nParents);

		// Add winning adults as parents
		Population.parentPopulation.clear();
		for (int i = 0; i < parentIndexes.length; i++) {
			Population.parentPopulation.add(Population.adultPopulation.get(parentIndexes[i]));
		}

	}

	// Sort a double[][] list by item in list[][0]
	public static double[][] sortByFirstInDoubleArray2(double[][] list) {
		for (int i = 0; i < list.length - 1; i++) {
			for (int j = 0; j < list.length - 1; j++) {
				if (list[j][0] > list[j + 1][0]) {
					double[] temp = list[j];
					list[j] = list[j + 1];
					list[j + 1] = temp;
				}
			}
		}
		return list;
	}

	// Returns rank in sorted list by index  
	public static int getRankByIndex(double[][] list, int index) {
		for (int i = 0; i < list.length; i++) {
			if (index == list[i][1])
				return i;
		}
		return 0;
	}

}
