package selection.parent;

import options.EAOptions;
import general.Individual;
import general.Population;


public class SigmaScaling extends ParentSelection{
	
	public SigmaScaling(EAOptions eaOptions){
		super(eaOptions);
	}
	
	@Override
	public void select() {
			// select a list of individuals
			// ExpVal(i,g) = 1 + ((f(i)) - avgf(g) / 2sigma(g))
			// g is the generation number of the EA,
			// f(i) is the fitness of individual i,
			// avgf(g) is the populations fitness average in generation g,
			// sigma(g) is the standard deviation of population fitness.

			double sumF = 0.0;
			int nmbOfIndividuals = Population.adultPopulation.size();
			double[] fitnessList = new double[nmbOfIndividuals];
			double[] probabilityLimits = new double[nmbOfIndividuals];
			double sigma = 0.0;

			for (Individual i : Population.adultPopulation) {
				sumF += i.getFitness();
				fitnessList[Population.adultPopulation.indexOf(i)] = i.getFitness();
			}

			double avgF = sumF / (double) nmbOfIndividuals;

			// find standard deviation sigma
			double var = 0.0;
			for (int i = 0; i < fitnessList.length; i++) {
				var += Math.pow((fitnessList[i] - avgF), 2);
			}

			var = var / (double) fitnessList.length;

			sigma = Math.sqrt(var);

			// Make list of limits for the rulettWheel
			for (int i = 0; i < probabilityLimits.length; i++) {
				if((double) Population.adultPopulation.get(i).getFitness() - avgF == 0.0){
					probabilityLimits[i] = 1.0;
				}else{
					probabilityLimits[i] = (1.0 + ((Population.adultPopulation.get(i).getFitness() - avgF) / (2 * sigma)));
				}
			}

			double sumExpVal = 0.0;

			for (int i = 0; i < probabilityLimits.length; i++) {
				sumExpVal += probabilityLimits[i];
			}

			probabilityLimits[0] = probabilityLimits[0] / sumExpVal;
			for (int i = 1; i < probabilityLimits.length; i++) {
				probabilityLimits[i] = (probabilityLimits[i] / sumExpVal) + probabilityLimits[i - 1];
			}

			// Run rulettWheel
			int[] parentIndexes = roulettWheel(probabilityLimits, nParents);
			
			// Add winning adults as parents
			Population.parentPopulation.clear();
			for (int i = 0; i < parentIndexes.length; i++) {
				Population.parentPopulation.add(Population.adultPopulation.get(parentIndexes[i]));
			}
		
	}

}
