package selection.parent;

import general.Individual;
import general.Population;

import java.util.ArrayList;

import options.EAOptions;



public class TournamentSelection extends ParentSelection{
	private final int groupSize;
	private final double e;
	
	public TournamentSelection(int groupSize, double e, EAOptions eaOptions){
		super(eaOptions);
		this.groupSize = groupSize;
		this.e = e;
	}
	
	@Override
	public void select() {
			// select a list of individuals
			ArrayList<Individual> winners = new ArrayList<Individual>();
			int nmbOfGroups = (int) (double) Population.adultPopulation.size() / groupSize;
			int nmbOfTournaments = (int) (double) Population.adultPopulation.size() / nmbOfGroups;

			for (int i = 0; i < nmbOfTournaments; i++) {
				runTournament(winners, nmbOfGroups);
			}
			
			if(winners.size() < nParents){
				runTournament(winners, nParents - winners.size());
			}
			
			// Add winning adults as parents
			Population.parentPopulation.clear();
			Population.parentPopulation.addAll(winners);
		
	}

	private void runTournament(ArrayList<Individual> winners, int nmbOfGroups) {
		ArrayList<Individual> tournamentGroup = new ArrayList<Individual>();
		ArrayList<Individual> candidates = new ArrayList<Individual>();
		candidates.addAll(Population.adultPopulation);
		for (int j = 0; j < nmbOfGroups; j++) {
			tournamentGroup.clear();

			// make tournament group of size groupSize and remove from
			// candidates
			for (int k = 0; k < groupSize; k++) {
				if (candidates.size() == 0) {
					break;
				} else {
					int index = (int) (Math.random() * candidates.size());
					tournamentGroup.add(candidates.get(index));
					candidates.remove(index);
				}
			}
			// run tournament
			double winnerProb = Math.random();
			
			if (winnerProb > e) {
				// best fitness wins
				double bestFitness = 0;
				int indexOfBest = 0;
				for (int l = 0; l < tournamentGroup.size(); l++) {
					if (tournamentGroup.get(l).getFitness() >= bestFitness) {
						bestFitness = tournamentGroup.get(l).getFitness();
						indexOfBest = l;
					}
				}
				winners.add(tournamentGroup.get(indexOfBest));
			} else {
				// random winner
				winners.add(tournamentGroup.get((int) Math.random() * tournamentGroup.size()));
			}
		}
	}

}
