package swarm;

import managers.ActionHandler;
import options.EAOptions;
import options.SimulatorOptions;
import general.Developmental;
import general.Genotype;
import general.Phenotype;

public class DevelopmentalBooleanToFloat extends Developmental {
	private EAOptions eaOptions;

	public DevelopmentalBooleanToFloat(EAOptions eaOptions) {
		this.eaOptions = eaOptions;
	}

	// Minimum values for doubles Weights, biases, gains, time constants
	float[] minFloats = new float[] { 0f, 0f, 0f, 0f, 0f, 0f, 0f, 0f, 0f, 0.0002f, 0.0002f, 0.0002f, 0.0002f };

	// Maximum values for doubles Weights, biases, gains, time constants
	float[] maxFloats = new float[] { 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f,  0.3f, 0.3f, 0.1f, 0.1f };

	// NumberOf: weigths, bias, gain, timeconstants
	// int[] limits = new int[] { 21, 25, 29 };

	@Override
	public Phenotype<Float> translate(Genotype<?> genotype) {
		// Get Genotype bitArray
		@SuppressWarnings("unchecked")
		Boolean[] bitArray = ((Genotype<Boolean>) genotype).getGenotypeArray();
		int firstBitInCurrentGroup = 0;

		// Calculate values for phenotypeArray
		Float[] phenotypeArray = new Float[bitArray.length / eaOptions.bitsPerGene];
		for (int i = 0; i < phenotypeArray.length; i++) {
			// Take a part of the bitArray
			boolean[] partBitArray = new boolean[eaOptions.bitsPerGene];
			for (int j = 0; j < partBitArray.length; j++) {
				partBitArray[j] = bitArray[firstBitInCurrentGroup + j];
			}

			// Translate from bit array to int
			long value = translateBinaryToInteger(partBitArray);

			// Calculate max int value
			long maxValue = (long) Math.pow(2, eaOptions.bitsPerGene) - 1;
			// Find double value between min and max, based on value/maxValue

			phenotypeArray[i] = findFloatValue(minFloats[i], maxFloats[i], value, maxValue);

			firstBitInCurrentGroup += eaOptions.bitsPerGene;
		}
		if(!SimulatorOptions.allowSelfAssembling)
			phenotypeArray[ActionHandler.ASSEMBLE]= 0f;
		
		if(!eaOptions.trainThresholds){
			phenotypeArray[9]= 0.1f;
			phenotypeArray[10]= 0.3f;
			phenotypeArray[11] = 0.005f;
			phenotypeArray[12] = 0.0002f;
		}
		return new Phenotype<Float>(phenotypeArray);
	}

	// Find double value between min and max, based on value/maxValue
	private static float findFloatValue(float min, float max, long value, long maxValue) {
		return (float) (min + (max - min) * ((double) value / maxValue));
	}

	// Translate from bit array to int
	private static long translateBinaryToInteger(boolean[] bitArray) {
		long sum = 0;
		for (int i = 0; i < bitArray.length; i++) {
			if (bitArray[bitArray.length - 1 - i])
				sum += Math.pow(2, i);
		}

		return sum;
	}
}
