package swarm;

import options.SimulatorOptions;
import setups.*;
import util.Util;
import evaluation.EvaluatorToLight;
import general.Fitness;
import general.Phenotype;
import general.Simulation;

public class FitnessSwarm extends Fitness {
	private final String environmentName;
	private final int NORMAL = 0, MINIMAL = 1, AVERAGE = 2, MEDIAN = 3;
	private int samples = 1;
	private int runMode;
	private Setup environment;

	public FitnessSwarm(String type, String environmentName) {
		this.environmentName = environmentName;
		this.environment = Setup.newSetup(environmentName);
		setRunMode(type);
	}
	
	public void setRunMode(String type){
		if (type.equals("NORMAL")) {
			runMode = NORMAL;
			samples = 1;
		} else if (type.startsWith("MINIMAL")) {
			runMode = MINIMAL;
			type = type.replace("MINIMAL", "");
			try {
				samples = Integer.parseInt(type);
			} catch (Exception e) {
				System.err.println("Could not parse samples{int} for MINIMAL, returning to default value 1");
			}
		} else if (type.startsWith("AVERAGE")) {
			runMode = AVERAGE;
			type = type.replace("AVERAGE", "");
			try {
				samples = Integer.parseInt(type);
			} catch (Exception e) {
				System.err.println("Could not parse samples{int} for AVERAGE, returning to default value 1");
			}
		}else if (type.startsWith("MEDIAN")) {
			runMode = MEDIAN;
			type = type.replace("MEDIAN", "");
			try {
				samples = Integer.parseInt(type);
			} catch (Exception e) {
				System.err.println("Could not parse samples{int} for AVERAGE, returning to default value 1");
			}
		}else{
			runMode = -1;
			System.err.println("Fitness type " + type + " does not exist, shutting down");
		}
	}

	@Override
	public double evaluation(Phenotype<?> phenotype) {
		SimulatorOptions.showGUI = false;
		phenotype.setNumberOfSamples(samples);
		
		if (runMode == MINIMAL) {
			double min = Float.MAX_VALUE;
			for (int i = 0; i < samples; i++) {
				double run = new Simulation(environment.generateWorld(phenotype), new EvaluatorToLight()).run();
				if(run < min){
					min = run;
				}
			}
			return min;
		} else if (runMode == AVERAGE) {
			double sum = 0.0;
			for (int i = 0; i < samples; i++) {
				sum += new Simulation(environment.generateWorld(phenotype), new EvaluatorToLight()).run();
			}
			return sum/samples;
		}else if (runMode == MEDIAN) {
			double[] fitnessValues = new double[samples];
			for (int i = 0; i < samples; i++) {
				fitnessValues[i] = new Simulation(environment.generateWorld(phenotype), new EvaluatorToLight()).run();
			}
			return Util.median(fitnessValues);
		}else {
			return new Simulation(environment.generateWorld(phenotype), new EvaluatorToLight()).run();
		}

	}

	@Override
	public String getTestName() {
		return environmentName;
	}
}
