package evaluation;

import environment_objects.World;
import general.Simulation;

import options.SimulatorOptions;

import org.jbox2d.common.Vec2;

import robot.DeadRobot;
import robot.Robot;

public class EvaluatorToLight extends Evaluator {
	private final float distanceWeight = 0.1f;
	private final float timeWeight = 0.9f;
	private final float distanceThreshold = 0.999f;
	private final float goalRadius = 0.25f;

	@Override
	public double evaluate(World world, float elapsedTime) {
		double distance = evaluateOnDistanceFromGoal(elapsedTime, world);
		// if (distance >= distanceThreshold) {
		return distanceWeight * distance + timeWeight * evaluateOnTime(elapsedTime, world);
		// }
		// else {
		// return distanceWeight * distance;
		// }
	}

	@Override
	public boolean isFinished(double fitness, World world) {
		for (Robot r : world.getRobots()) {
			if (!r.hasReachedGoalOnce()) {
				return false;
			}
		}
		return true;
	}

	private double evaluateOnDistanceFromGoal(float elapsedTime, World world) {
		if (world.getRobots().size() == 0 || world.getGoalObject() == null) {
			return 0;
		}

		int nmbOfRobots = world.getRobots().size() + world.getDeadRobots().size();

		Vec2 goalPosition = world.getGoalObject().getBody().getPosition();
		float totalDistanceFromGoal = 0f;

		for (Robot robot : world.getRobots()) {
			float distanceFromGoal = calcDistanceFromGoal(robot.getBody().getPosition(), goalPosition);
			if (distanceFromGoal > 0 && !robot.hasReachedGoalOnce()) {
				robot.setTimeUsed(elapsedTime);
			} else {
				robot.setHasReachedGoalOnce(true);
			}
			totalDistanceFromGoal += distanceFromGoal;
		}
		totalDistanceFromGoal += world.getDeadRobots().size() * world.getHeight();
		float fitness = (1f - (totalDistanceFromGoal / (nmbOfRobots * world.getHeight())));
		return fitness;
	}

	private float evaluateOnTime(float elapsedTime, World world) {
		float time = Simulation.endTime;

		float timeTotal = 0;
		for (Robot r : world.getRobots()) {
			if (r.hasReachedGoalOnce()) {
				timeTotal += r.getTimeUsed();
			} else {
				timeTotal += Simulation.endTime;
			}
		}

		timeTotal += Simulation.endTime * world.getDeadRobots().size();

		time = timeTotal / (world.getRobots().size() + world.getDeadRobots().size());

		return (1f - time / Simulation.endTime);
	}

	private float calcDistanceFromGoal(Vec2 robotPosition, Vec2 goalPosition) {
		Vec2 distVector = goalPosition.sub(robotPosition);
		float distance = distVector.length() - (2 * Robot.getSize());
		return Math.max(distance - goalRadius, 0f);
	}
}
