package general;

import controller.ArbitrationController;
import objects.BodyObject;
import options.SimulatorOptions;
import robot.Robot;
import util.PerformanceTester;
import environment_objects.World;
import evaluation.Evaluator;
import evaluation.EvaluatorToLight;

public class Simulation {

	/** Constants */

	public static final float timeStep = 1.0f / 30.f;
	public static final float endTime = 90;
	private final int velocityIterations = 6;
	private final int positionIterations = 2;

	/** Variables */

	private World world;
	private Gui gui;
	private Evaluator evaluator = new EvaluatorToLight();

	/** Constructor */

	public Simulation(World world, Evaluator evaluator) {
		this.world = world;
		this.evaluator = evaluator;
	}

	/** Public Methods */

	public double run() {
		float elapsedTime = 0;
		boolean isFinished = false;
		double currentFitness = 0;

		if (SimulatorOptions.showGUI)
			gui = new Gui(world, timeStep);

		while (elapsedTime < endTime && !isFinished) {
			// PerformanceTester.startTest("step");
			elapsedTime += timeStep;

			world.getGround().updateWindAreas();

			// Read sensors and update actuators
			for (Robot r : world.getRobots()) {
				r.run(elapsedTime);
			}

			// Update the physics of the world
			for (BodyObject object : world.getWorldObjects()) {
				object.update();
			}

			// Do a step
			world.step(timeStep, velocityIterations, positionIterations);
			world.clearRemoved();

			// Update statistics
			currentFitness = evaluator.evaluateOnInterval(world, elapsedTime);
			isFinished = evaluator.isFinished(currentFitness, world);

			if (world.getRobots().size() == 0) {
				currentFitness = 0;
				isFinished = true;
			}
			// PerformanceTester.endTest("step");
			// Draw world
			if (SimulatorOptions.showGUI)
				gui.repaintGUI(elapsedTime, currentFitness);
		}

		if (world.getRobots().size() > 0 && world.getRobots().get(0).getController() instanceof ArbitrationController) {
			if (((ArbitrationController) world.getRobots().get(0).getController()).getPhenotype() != null) {
				for (Robot r : world.getRobots()) {
					((ArbitrationController) (r.getController())).addConnectionToPhenotype();
				}
			}
		}

		return currentFitness;
	}
}
