package joints;

import general.Gui;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;

import options.SimulatorOptions;

import org.jbox2d.common.Vec2;
import org.jbox2d.dynamics.joints.DistanceJoint;
import org.jbox2d.dynamics.joints.DistanceJointDef;

import robot.Gripper;
import robot.Robot;

import util.Util;

public class ConnectionJoint {

	private DistanceJoint joint;
	private DistanceJointDef jointDef;
	private Robot robotA;
	private Robot robotB;
	
	public ConnectionJoint(Robot robotA, Robot robotB, Vec2 connectionPointA, Vec2 connectionPointB){
		this.robotA = robotA;
		this.robotB = robotB;
		robotA.setConnectionJoint(this);
		
		jointDef = new DistanceJointDef();
		jointDef.bodyA = robotA.body;
		jointDef.bodyB = robotB.body;
		
		jointDef.localAnchorA.set(connectionPointA);
		jointDef.localAnchorB.set(connectionPointB);
		
		jointDef.collideConnected = true;
		
		jointDef.length = Gripper.maxGripperDistance;
		
		jointDef.frequencyHz = 0f;
		jointDef.dampingRatio = 0f;
	}
	
	public DistanceJoint getJoint(){
		return joint;
	}
	
	public DistanceJointDef getJointDef(){
		return jointDef;
	}
	
	public void setJoint(DistanceJoint joint){
		this.joint = joint;
	}
	
	public void draw(Graphics2D g) {
		if(!joint.isActive() ||SimulatorOptions.onlyShowEnvironment)
			return;
		
		Vec2 posAGui = jointDef.bodyA.getWorldPoint(joint.getLocalAnchorA());
		posAGui.mulLocal(Gui.scale);
		
		Vec2 posBGui = jointDef.bodyB.getWorldPoint(joint.getLocalAnchorB());
		posBGui.mulLocal(Gui.scale);

		g.setColor(Color.RED);
		g.setStroke(new BasicStroke(8f));
		g.drawLine((int)posAGui.x, (int)posAGui.y, (int)posBGui.x, (int)posBGui.y);

		g.setColor(Color.WHITE);
		g.setStroke(new BasicStroke(1f));
		g.drawLine((int)posAGui.x, (int)posAGui.y, (int)posBGui.x, (int)posBGui.y);
		

		g.setStroke(Util.thinLine);
	}
	
	public Robot getRobotA() {
		return robotA;
	}

	public Robot getRobotB() {
		return robotB;
	}

}
