package joints;

import environment_objects.Ground;

import org.jbox2d.common.Vec2;
import org.jbox2d.dynamics.joints.FrictionJoint;
import org.jbox2d.dynamics.joints.FrictionJointDef;

import robot.Robot;

public class GroundFrictionJoint {
	private Ground ground;
	private FrictionJointDef jointDef;
	private FrictionJoint joint;
	private float friction;

	public GroundFrictionJoint(Robot robot, Ground ground) {
		this.ground = ground;
		jointDef = new FrictionJointDef();
		jointDef.bodyA = robot.getBody();
		jointDef.bodyB = ground.getBody();
		jointDef.maxForce = 0;
		jointDef.maxTorque = 0;
	}

	public FrictionJoint getJoint() {
		return joint;
	}

	public FrictionJointDef getJointDef() {
		return jointDef;
	}

	public void setJoint(FrictionJoint joint) {
		this.joint = joint;
	}

	public void update(Vec2 position, boolean isMoving) {
		friction = ground.getSurfaceFriction(position, isMoving);
		float totalMass = joint.getBodyA().getMass();
		float maxForce = totalMass * 9.81f * friction;
		joint.setMaxForce(maxForce);
		joint.setMaxTorque(0.002f);// 0.001f);
	}

	public float getFriction() {
		return friction;
	}
}
