package objects;

import general.Gui;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Ellipse2D;
import org.jbox2d.collision.shapes.CircleShape;
import org.jbox2d.common.Vec2;
import org.jbox2d.dynamics.BodyType;
import org.jbox2d.dynamics.FixtureDef;

import util.Tuple;
import util.Util;

public class LightSource extends BodyObject {
	public Ellipse2D ellipse;
	private final float size = 0.035f;
	protected Light light = null;
	private boolean isGoal = false;

	public LightSource(Vec2 position, Color color) {
		super(position, BodyType.STATIC);
		bd.angle = 0f;
		shape = new CircleShape();
		shape.m_radius = size;
		if(color != Color.BLACK)
			light = new Light(color);
	}

	public FixtureDef setFixtureDef() {
		FixtureDef fd = new FixtureDef();
		fd.shape = shape;
		fd.density = 40.0f;
		fd.friction = 0.3f;
		fd.restitution = 0.1f;
		return fd;
	}

	@Override
	public void update() {
	}
	
	public float getSize() {
		return size;
	}
	
	public void setLight(Light light) {
		this.light = light;
	}

	@Override
	public void draw(Graphics2D g) {
		double scaledRadius = shape.m_radius * Gui.scale;
		ellipse = new Ellipse2D.Double(-scaledRadius, -scaledRadius, 2 * scaledRadius, 2 * scaledRadius);
		float x = body.getPosition().x * Gui.scale;
		float y = body.getPosition().y * Gui.scale;
		g.translate(x, y);
		if(light != null){
			g.setColor(light.getColor());
		}else{
			g.setColor(Color.BLACK);
		}
		g.fill(ellipse);
		
		
		if(isGoal){
			String goal = "Goal";
			g.setColor(Color.BLACK);
			g.drawString(goal, -Util.getStringWithOnScreen(g, goal) / 2, -20);
		}
		g.translate(-x, -y);
	}

	@Override
	public Tuple<Light, Float> getLightProperties(float normalAngle) {
		return new Tuple<Light, Float>(light, 1f);
	}
	
	@Override
	public boolean isOccupied(Vec2 position) {
		float dX = getBody().getPosition().x - position.x;
		float dY = getBody().getPosition().y - position.y;
		float l = (float) (Math.sqrt(Math.pow(dX, 2) + Math.pow(dY, 2)));
		// System.out.println(radius > l);
		return size > l;
	}

	public void setGoal(boolean isGoal) {
		this.isGoal = isGoal;
	}
}
