package objects;

import java.awt.Graphics2D;

import org.jbox2d.collision.shapes.PolygonShape;
import org.jbox2d.common.Vec2;
import org.jbox2d.dynamics.BodyType;
import org.jbox2d.dynamics.FixtureDef;
import util.Tuple;

public class Wall extends BodyObject {
	private float width;
	private float height;

	public Wall(Vec2 position, float width, float height) {
		super(position, BodyType.STATIC);
		shape = new PolygonShape();
		((PolygonShape) shape).setAsBox(width, height);

		this.width = width;
		this.height = height;
	}

	public FixtureDef setFixtureDef() {
		FixtureDef fd = new FixtureDef();
		fd.shape = shape;
		fd.density = 1.0f;
		fd.friction = 0.05f;
		return fd;
	}

	@Override
	public void update() {
	}

	@Override
	public void draw(Graphics2D g) {
	}

	public float getDirectionToWall(Vec2 position) {
		if (isVertical()) {
			boolean robotToLeft = position.x < getBody().getPosition().x;
			return (robotToLeft) ? 0.0f : (float) (Math.PI);
		} else {
			boolean robotAbove = position.y < getBody().getPosition().y;
			return (robotAbove) ? (float) (Math.PI / 2.0f) : (float) (Math.PI * 3.0f / 2.0f);
		}
	}

	public boolean isVertical() {
		return (width == 0.0f);
	}

	public float getHeight() {
		return height;
	}

	public float getWidth() {
		return width;
	}

	public boolean IsPointOnWall(Vec2 point) {
		float threshold = 0.001f;
		float minX = getBody().getPosition().x - threshold;
		float minY = getBody().getPosition().y - threshold;
		float maxX = getBody().getPosition().x + threshold + getWidth();
		float maxY = getBody().getPosition().y + threshold + getHeight();

		return (point.x >= minX && point.x <= maxX && point.y >= minY && point.y <= maxY);
	}

	@Override
	public Tuple<Light, Float> getLightProperties(float normalAngle) {
		return null;
	}

	@Override
	public boolean isOccupied(Vec2 position) {
		return false;
	}
}
