package robot;

import general.Simulation;

import java.awt.Graphics2D;
import org.jbox2d.common.Vec2;

public class Accelerometer extends Sensor {
	private Robot robot;
	private boolean robotIsMoving;
	private Vec2 oldPosition;
	private float timeSinceMoved;
	
	public Accelerometer(Robot robot){
		this.robot = robot;
		robotIsMoving = false;
		timeSinceMoved = 0f;
	}
	
	public void readSensor() {
		if(oldPosition != null){
			Vec2 diff = oldPosition.sub(robot.getBody().getPosition());
			robotIsMoving = diff.length() > 0.0001f;
		}else{
			robotIsMoving = true;
		}
		oldPosition = robot.getBody().getPosition().clone();
		
		if (robotIsMoving) {
			timeSinceMoved = 0;
		} else {
			timeSinceMoved += Simulation.timeStep;
		}
	}
	
	public void resetTimeSinceMoved(){
		timeSinceMoved = 0;
	}
	
	public float getTimeSinceMoved() {
		return timeSinceMoved;
	}

	@Override
	public void draw(Graphics2D g) {
	}
}
