package setups;

import environment_objects.IceRectangle;
import environment_objects.WindArea;
import environment_objects.World;
import general.DistributeRandomly;
import general.Phenotype;

import java.awt.Color;

import objects.LightSource;
import options.SimulatorOptions;

import org.jbox2d.common.Vec2;

import robot.Robot;
import controller.ArbitrationController;

public class OpposingWind extends Setup {
	private float windVelocity;

	public OpposingWind(float windVelocity) {
		this.windVelocity = windVelocity;
	}

	@SuppressWarnings("unchecked")
	@Override
	public World generateWorld(Phenotype<?> phenotype) {
		World world = new World(1.5f, 3.0f);
		world.getGround().setStartingArea(0.4f, 2.25f, 0.7f, 0.7f);

		int numberOfRobots = 4;
		if(phenotype != null){
			phenotype.setNumberOfRobotsPerSimulation(numberOfRobots);
		}
		
		for (int i = 0; i < numberOfRobots; i++) {
			world.addObject(new Robot(world, new ArbitrationController((Phenotype<Float>) phenotype)));
		}
		
		DistributeRandomly.distributeRobotsRandomly(world);
		
		LightSource lightSource = new LightSource(new Vec2(0.75f, 0.2f), Color.RED);
		world.setGoalObject(lightSource);
		world.addObject(lightSource);
		
		world.getGround().addIceArea(new IceRectangle(new Vec2(0.0f, 0.6f), new Vec2(world.getWidth(), 1f)));
		world.getGround().addWindArea(new WindArea(new Vec2(0f, 0f), new Vec2(world.getWidth(), world.getHeight()), windVelocity, WindArea.SOUTH, world));
		
		SimulatorOptions.drawController =  true;
		
		return world;
	}

}
