package setups;
import environment_objects.IceRectangle;
import environment_objects.WindArea;
import environment_objects.World;
import general.DistributeRandomly;
import general.Phenotype;

import java.awt.Color;

import objects.LightSource;
import options.SimulatorOptions;

import org.jbox2d.common.Vec2;

import robot.Robot;
import controller.ArbitrationController;

public class OpposingWindObstacles extends Setup{
		private float windVelocity;

		public OpposingWindObstacles(float windVelocity) {
			this.windVelocity = windVelocity;
		}

		@SuppressWarnings("unchecked")
		@Override
		public World generateWorld(Phenotype<?> phenotype) {
			World world = new World(1.5f, 3.0f);
			world.getGround().setStartingArea(0.4f, 2.25f, 0.7f, 0.7f);

			int numberOfRobots = 4;
			if(phenotype != null){
				phenotype.setNumberOfRobotsPerSimulation(numberOfRobots);
			}
			
			for (int i = 0; i < numberOfRobots; i++) {
				world.addObject(new Robot(world, new ArbitrationController((Phenotype<Float>) phenotype)));
			}
			
			DistributeRandomly.distributeRobotsRandomly(world);
			
			LightSource lightSource = new LightSource(new Vec2(0.75f, 0.2f), Color.RED);
			world.setGoalObject(lightSource);
			world.addObject(lightSource);
			
			world.addObject(new LightSource(new Vec2(0.05f,0.65f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(0.08f,1.2f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(1.45f,0.7f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(1.05f,1.5f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(0.35f,0.9f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(0.55f,1.4f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(1.1f,1.1f),Color.BLACK));
			world.addObject(new LightSource(new Vec2(0.8f,0.8f),Color.BLACK));
			
			world.getGround().addIceArea(new IceRectangle(new Vec2(0.0f, 0.6f), new Vec2(world.getWidth(), 1f)));
			world.getGround().addWindArea(new WindArea(new Vec2(0f, 0f), new Vec2(world.getWidth(), world.getHeight()), windVelocity, WindArea.SOUTH, world));
			
			SimulatorOptions.drawController =  true;
			
			return world;
		}
}
