package setups;

import options.SimulatorOptions;
import environment_objects.World;
import general.Gui;
import general.Phenotype;

public abstract class Setup {

	public abstract World generateWorld(Phenotype<?> phenotype);

	public static Setup newSetup(String setupName) {
		Gui.setUpName = setupName;
		
		if (setupName.endsWith(".ini")) {
			return new SetupFromWorldFile(setupName);
		}

		if (setupName.startsWith("OpposingWindObstacles")) {
			try {
				String argumentsString = setupName.replace("OpposingWindObstacles", "");
				String[] arguments = argumentsString.split(",");
				float input = SimulatorOptions.windVelocity;
				if(!arguments[0].equals("")){
					 input = Float.parseFloat(arguments[0]);
				}
				return new OpposingWindObstacles(input);
			} catch (Exception e) {
				System.err.println(setupName + " not found");
				e.printStackTrace();
				return null;
			}

		} else if (setupName.startsWith("OpposingWind")) {
			try {
				String argumentsString = setupName.replace("OpposingWind", "");
				String[] arguments = argumentsString.split(",");
				float input = SimulatorOptions.windVelocity;
				if(!arguments[0].equals("")){
					 input = Float.parseFloat(arguments[0]);
				}
				return new OpposingWind(input);
			} catch (Exception e) {
				System.err.println(setupName + " not found");
				e.printStackTrace();
				return null;
			}

		} else if (setupName.startsWith("SideWindObstacles")) {
			try {
				String argumentsString = setupName.replace("SideWindObstacles", "");
				String[] arguments = argumentsString.split(",");
				float input = SimulatorOptions.windVelocity;
				if(!arguments[0].equals("")){
					 input = Float.parseFloat(arguments[0]);
				}
				return new SideWindObstacles(input);
			} catch (Exception e) {
				System.err.println(setupName + " not found");
				e.printStackTrace();
				return null;
			}

		} else if (setupName.startsWith("WindyAndHoles")) {
			try {
				String argumentsString = setupName.replace("WindyAndHoles", "");
				String[] arguments = argumentsString.split(",");
				float input = SimulatorOptions.windVelocity;
				if(!arguments[0].equals("")){
					 input = Float.parseFloat(arguments[0]);
				}
				return new WindyAndHoles(input);
			} catch (Exception e) {
				System.err.println(setupName + " not found");
				e.printStackTrace();
				return null;
			}

		} else {
			System.err.println("Environment setup " + setupName + " does not exist, shutting down");
			System.exit(0);
			return null;
		}

	}

}
