package test_setups;

import environment_objects.IceCircle;
import environment_objects.IceRectangle;
import environment_objects.WindArea;
import environment_objects.World;
import general.Phenotype;
import options.SimulatorOptions;

import org.jbox2d.common.Vec2;

import robot.Robot;
import setups.Setup;
import controller.ForwardTestController;

public class IceTestSetup extends Setup {

	@Override
	public World generateWorld(Phenotype<?> phenotype) {
		World world = new World(1, 1);

		float commonSpeed = 1.0f;
		float stopAtTime = 3.5f;
		world.addObject(new Robot(new Vec2(0.95f, 0.1f), 180.0f, world, new ForwardTestController(stopAtTime, commonSpeed, commonSpeed)));
		world.addObject(new Robot(new Vec2(0.95f, 0.3f), 180.0f, world, new ForwardTestController(stopAtTime, commonSpeed, commonSpeed)));
		world.addObject(new Robot(new Vec2(0.95f, 0.5f), 180.0f, world, new ForwardTestController(stopAtTime, commonSpeed, commonSpeed)));
		world.addObject(new Robot(new Vec2(0.95f, 0.7f), 180.0f, world, new ForwardTestController(stopAtTime, commonSpeed, commonSpeed)));
		world.addObject(new Robot(new Vec2(0.95f, 0.9f), 180.0f, world, new ForwardTestController(stopAtTime, commonSpeed, commonSpeed)));

		// Add ice areas
		world.getGround().addIceArea(new IceCircle(new Vec2(0.1f, 0.1f), 0.15f));
		world.getGround().addIceArea(new IceRectangle(new Vec2(0.45f, 0.25f), new Vec2(0.4f, 0.35f)));
		world.getGround().addIceArea(new IceRectangle(new Vec2(0.85f, 0.4f), new Vec2(0.15f, 0.2f)));

		world.getGround().addIceArea(new IceRectangle(new Vec2(0.2f, 0.8f), new Vec2(0.5f, 0.2f)));
		world.getGround().addWindArea(new WindArea(new Vec2(0f, 0.8f), new Vec2(1f, 0.2f), 5, WindArea.EAST, world));

		SimulatorOptions.drawSensors = false;
		WindArea.drawOutline = true;
		return world;
	}

}
